# -*- coding: utf-8 -*-

# Eeterm -- Terminal for Eemyle
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2003-2019 Easter-eggs
# https://gitlab.easter-eggs.com/ee/eeterm
#
# This file is part of Eeterm.
#
# Eeterm is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Eeterm is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import logging
from optparse import OptionParser
import os
import sys
import tempfile

from eessh.api import api
from eessh.client import EeSSHClient
from eessh.config import config as eessh_config

from eeterm.config import config as eeterm_config

log = logging.getLogger(__name__)


def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]

    parser = OptionParser(u'usage: %prog [options] <config_uri>')

    parser.add_option(
        '-d',
        '--debug',
        action='store_true',
        help=u'Show debug messages'
    )

    options, arguments = parser.parse_args(argv)

    # EeSSH initialization
    config_filepath = os.path.join(os.path.expanduser('~'), '.config', 'eemyle', 'eesshrc') # XXX hard-coded path (and repeated elsewhere)
    if not eessh_config.load(config_filepath):
        parser.error('Failed to load configuration from file {0}'.format(config_filepath))

    # EeTerm initialization
    config_filepath = os.path.join(os.path.expanduser('~'), '.config', 'eemyle', 'eetermrc') # XXX hard-coded path (and repeated elsewhere)
    if not eeterm_config.load(config_filepath):
        parser.error('Failed to load configuration from file {0}'.format(config_filepath))

    # Set instance CTRL/DATA fifo filepaths
    pid = os.getpid()

    EeSSHClient.CTRL_FIFO = tempfile.mktemp(prefix='eeterm-{0}-'.format(pid), suffix='-ctrl')
    EeSSHClient.DATA_FIFO = tempfile.mktemp(prefix='eeterm-{0}-'.format(pid), suffix='-data')

    # Logging
    log = logging.getLogger()
    if options.debug:
        log.setLevel(logging.DEBUG)

    if not api.initialize():
        log.warning('Failed to initialize API connector')

    # Gtk initialization
    import gi
    gi.require_version('Gdk', '3.0')
    gi.require_version('Gtk', '3.0')
    gi.require_version('Vte', '2.91')

    # Launch application
    from eeterm.core import Application
    app = Application()
    app.run()
